<?php declare(strict_types = 1);

namespace Drupal\notify_widget\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\notify_widget\NotifyWidgetApi;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Notify Widget routes.
 */
final class NotificationsController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    private readonly NotifyWidgetApi $notifyWidgetApi,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('notify_widget.api'),
    );
  }

  /**
   * Builds the response.
   *
   * @param \Drupal\user\Entity\User|null $user
   *   The user object.
   */
  public function __invoke(User $user = NULL): array {
    // Get the notifications for the user.
    $notifications = $this->notifyWidgetApi->getNotificationsForUser();

    $header = [
      ['data' => $this->t('Date/Time')],
      ['data' => $this->t('Notification Type')],
      ['data' => $this->t('Title')],
      ['data' => $this->t('Text')],
      ['data' => $this->t('Read')],
      ['data' => ''],
    ];

    $rows = [];
    foreach ($notifications as $notification) {
      $rows[$notification->id] = [
        ['data' => date('d/m/Y H:i', (int) $notification->timestamp)],
        ['data' => $notification->notification_type],
        ['data' => $notification->notification_title],
        ['data' => $notification->notification_text],
        ['data' => $notification->read ? $this->t('Yes') : $this->t('No')],
        ['data' => ''],
      ];
    }

    $build['notifications'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => $this->t('You have no notifications.'),
    ];

    return $build;
  }

}
